# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'pyqt_filter_stacked.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1141, 590)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.stackedWindows = QtWidgets.QStackedWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.stackedWindows.sizePolicy().hasHeightForWidth())
        self.stackedWindows.setSizePolicy(sizePolicy)
        self.stackedWindows.setObjectName("stackedWindows")
        self.classic = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.classic.sizePolicy().hasHeightForWidth())
        self.classic.setSizePolicy(sizePolicy)
        self.classic.setObjectName("classic")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.classic)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.splitter = QtWidgets.QSplitter(self.classic)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.splitter.sizePolicy().hasHeightForWidth())
        self.splitter.setSizePolicy(sizePolicy)
        self.splitter.setMinimumSize(QtCore.QSize(600, 0))
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setObjectName("splitter")
        self.tabGroup = QtWidgets.QTabWidget(self.splitter)
        self.tabGroup.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.tabGroup.sizePolicy().hasHeightForWidth())
        self.tabGroup.setSizePolicy(sizePolicy)
        self.tabGroup.setTabsClosable(False)
        self.tabGroup.setMovable(False)
        self.tabGroup.setObjectName("tabGroup")
        self.freqTab = QtWidgets.QWidget()
        self.freqTab.setObjectName("freqTab")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.freqTab)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.freqPlot = GrFilterPlotWidget(self.freqTab)
        self.freqPlot.setObjectName("freqPlot")
        self.horizontalLayout_9.addWidget(self.freqPlot)
        self.tabGroup.addTab(self.freqTab, "")
        self.timeTab = QtWidgets.QWidget()
        self.timeTab.setObjectName("timeTab")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.timeTab)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.timePlot = GrFilterPlotWidget(self.timeTab)
        self.timePlot.setObjectName("timePlot")
        self.horizontalLayout_10.addWidget(self.timePlot)
        self.tabGroup.addTab(self.timeTab, "")
        self.phaseTab = QtWidgets.QWidget()
        self.phaseTab.setObjectName("phaseTab")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.phaseTab)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.phasePlot = GrFilterPlotWidget(self.phaseTab)
        self.phasePlot.setObjectName("phasePlot")
        self.horizontalLayout_11.addWidget(self.phasePlot)
        self.tabGroup.addTab(self.phaseTab, "")
        self.groupTab = QtWidgets.QWidget()
        self.groupTab.setObjectName("groupTab")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.groupTab)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.groupPlot = GrFilterPlotWidget(self.groupTab)
        self.groupPlot.setObjectName("groupPlot")
        self.horizontalLayout_12.addWidget(self.groupPlot)
        self.tabGroup.addTab(self.groupTab, "")
        self.fcTab = QtWidgets.QWidget()
        self.fcTab.setObjectName("fcTab")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.fcTab)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.filterCoeff = QtWidgets.QTextBrowser(self.fcTab)
        self.filterCoeff.setObjectName("filterCoeff")
        self.horizontalLayout_7.addWidget(self.filterCoeff)
        self.tabGroup.addTab(self.fcTab, "")
        self.impresTab = QtWidgets.QWidget()
        self.impresTab.setObjectName("impresTab")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.impresTab)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.impresPlot = GrFilterPlotWidget(self.impresTab)
        self.impresPlot.setObjectName("impresPlot")
        self.horizontalLayout_6.addWidget(self.impresPlot)
        self.tabGroup.addTab(self.impresTab, "")
        self.stepresTab = QtWidgets.QWidget()
        self.stepresTab.setObjectName("stepresTab")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.stepresTab)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.stepresPlot = GrFilterPlotWidget(self.stepresTab)
        self.stepresPlot.setObjectName("stepresPlot")
        self.horizontalLayout_8.addWidget(self.stepresPlot)
        self.tabGroup.addTab(self.stepresTab, "")
        self.pdelayTab = QtWidgets.QWidget()
        self.pdelayTab.setObjectName("pdelayTab")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.pdelayTab)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.pdelayPlot = GrFilterPlotWidget(self.pdelayTab)
        self.pdelayPlot.setObjectName("pdelayPlot")
        self.horizontalLayout_17.addWidget(self.pdelayPlot)
        self.tabGroup.addTab(self.pdelayTab, "")
        self.filterspecView = QtWidgets.QTabWidget(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filterspecView.sizePolicy().hasHeightForWidth())
        self.filterspecView.setSizePolicy(sizePolicy)
        self.filterspecView.setMinimumSize(QtCore.QSize(613, 250))
        self.filterspecView.setBaseSize(QtCore.QSize(0, 100))
        self.filterspecView.setDocumentMode(False)
        self.filterspecView.setTabsClosable(False)
        self.filterspecView.setObjectName("filterspecView")
        self.bandDiagram = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bandDiagram.sizePolicy().hasHeightForWidth())
        self.bandDiagram.setSizePolicy(sizePolicy)
        self.bandDiagram.setObjectName("bandDiagram")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.bandDiagram)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.bandView = BandGraphicsView(self.bandDiagram)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.bandView.sizePolicy().hasHeightForWidth())
        self.bandView.setSizePolicy(sizePolicy)
        self.bandView.setMinimumSize(QtCore.QSize(525, 249))
        self.bandView.setObjectName("bandView")
        self.horizontalLayout_13.addWidget(self.bandView)
        self.filterspecView.addTab(self.bandDiagram, "")
        self.poleZero = QtWidgets.QWidget()
        self.poleZero.setAutoFillBackground(False)
        self.poleZero.setObjectName("poleZero")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.poleZero)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.pzstatusBar = QtWidgets.QStatusBar(self.poleZero)
        self.pzstatusBar.setObjectName("pzstatusBar")
        self.gridLayout_2.addWidget(self.pzstatusBar, 1, 0, 1, 3)
        self.pzgroupBox = QtWidgets.QGroupBox(self.poleZero)
        self.pzgroupBox.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.pzgroupBox.setTitle("")
        self.pzgroupBox.setFlat(False)
        self.pzgroupBox.setCheckable(False)
        self.pzgroupBox.setObjectName("pzgroupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.pzgroupBox)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.addzeroPush = QtWidgets.QToolButton(self.pzgroupBox)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/add_zero.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.addzeroPush.setIcon(icon)
        self.addzeroPush.setIconSize(QtCore.QSize(16, 16))
        self.addzeroPush.setCheckable(True)
        self.addzeroPush.setObjectName("addzeroPush")
        self.verticalLayout_3.addWidget(self.addzeroPush)
        self.addpolePush = QtWidgets.QToolButton(self.pzgroupBox)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/add_pole.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.addpolePush.setIcon(icon1)
        self.addpolePush.setCheckable(True)
        self.addpolePush.setObjectName("addpolePush")
        self.verticalLayout_3.addWidget(self.addpolePush)
        self.delPush = QtWidgets.QToolButton(self.pzgroupBox)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/remove_red.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.delPush.setIcon(icon2)
        self.delPush.setCheckable(True)
        self.delPush.setObjectName("delPush")
        self.verticalLayout_3.addWidget(self.delPush)
        self.conjPush = QtWidgets.QToolButton(self.pzgroupBox)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/conjugate.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.conjPush.setIcon(icon3)
        self.conjPush.setIconSize(QtCore.QSize(16, 16))
        self.conjPush.setCheckable(True)
        self.conjPush.setObjectName("conjPush")
        self.verticalLayout_3.addWidget(self.conjPush)
        self.gridLayout_2.addWidget(self.pzgroupBox, 0, 2, 1, 1)
        self.pzPlot = PzPlot(self.poleZero)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pzPlot.sizePolicy().hasHeightForWidth())
        self.pzPlot.setSizePolicy(sizePolicy)
        self.pzPlot.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.pzPlot.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.pzPlot.setLineWidth(1)
        self.pzPlot.setInteractive(True)
        self.pzPlot.setObjectName("pzPlot")
        self.gridLayout_2.addWidget(self.pzPlot, 0, 1, 1, 1)
        self.filterspecView.addTab(self.poleZero, "")
        self.horizontalLayout.addWidget(self.splitter)
        self.quickFrame = QtWidgets.QFrame(self.classic)
        self.quickFrame.setMinimumSize(QtCore.QSize(180, 200))
        self.quickFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.quickFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.quickFrame.setObjectName("quickFrame")
        self.responseBox = QtWidgets.QGroupBox(self.quickFrame)
        self.responseBox.setGeometry(QtCore.QRect(10, 10, 161, 251))
        self.responseBox.setObjectName("responseBox")
        self.checkMagres = QtWidgets.QCheckBox(self.responseBox)
        self.checkMagres.setGeometry(QtCore.QRect(10, 40, 151, 19))
        self.checkMagres.setChecked(True)
        self.checkMagres.setObjectName("checkMagres")
        self.checkPhase = QtWidgets.QCheckBox(self.responseBox)
        self.checkPhase.setGeometry(QtCore.QRect(10, 60, 151, 19))
        self.checkPhase.setChecked(True)
        self.checkPhase.setObjectName("checkPhase")
        self.checkGdelay = QtWidgets.QCheckBox(self.responseBox)
        self.checkGdelay.setGeometry(QtCore.QRect(10, 80, 111, 19))
        self.checkGdelay.setChecked(True)
        self.checkGdelay.setObjectName("checkGdelay")
        self.checkPdelay = QtWidgets.QCheckBox(self.responseBox)
        self.checkPdelay.setGeometry(QtCore.QRect(10, 100, 111, 19))
        self.checkPdelay.setChecked(True)
        self.checkPdelay.setObjectName("checkPdelay")
        self.checkImpulse = QtWidgets.QCheckBox(self.responseBox)
        self.checkImpulse.setGeometry(QtCore.QRect(10, 120, 141, 19))
        self.checkImpulse.setChecked(True)
        self.checkImpulse.setObjectName("checkImpulse")
        self.checkStep = QtWidgets.QCheckBox(self.responseBox)
        self.checkStep.setGeometry(QtCore.QRect(10, 140, 131, 19))
        self.checkStep.setChecked(True)
        self.checkStep.setObjectName("checkStep")
        self.checkGrid = QtWidgets.QCheckBox(self.responseBox)
        self.checkGrid.setGeometry(QtCore.QRect(10, 160, 85, 19))
        self.checkGrid.setObjectName("checkGrid")
        self.checkFcoeff = QtWidgets.QCheckBox(self.responseBox)
        self.checkFcoeff.setGeometry(QtCore.QRect(10, 180, 131, 19))
        self.checkFcoeff.setChecked(True)
        self.checkFcoeff.setObjectName("checkFcoeff")
        self.checkKeepcur = QtWidgets.QCheckBox(self.responseBox)
        self.checkKeepcur.setGeometry(QtCore.QRect(10, 200, 141, 19))
        self.checkKeepcur.setObjectName("checkKeepcur")
        self.groupSpecs = QtWidgets.QGroupBox(self.quickFrame)
        self.groupSpecs.setGeometry(QtCore.QRect(10, 280, 161, 91))
        self.groupSpecs.setObjectName("groupSpecs")
        self.checkBand = QtWidgets.QCheckBox(self.groupSpecs)
        self.checkBand.setGeometry(QtCore.QRect(10, 20, 111, 19))
        self.checkBand.setChecked(True)
        self.checkBand.setObjectName("checkBand")
        self.checkPzplot = QtWidgets.QCheckBox(self.groupSpecs)
        self.checkPzplot.setGeometry(QtCore.QRect(10, 40, 131, 19))
        self.checkPzplot.setChecked(True)
        self.checkPzplot.setObjectName("checkPzplot")
        self.sysParamsBox = QtWidgets.QGroupBox(self.quickFrame)
        self.sysParamsBox.setGeometry(QtCore.QRect(10, 390, 161, 91))
        self.sysParamsBox.setObjectName("sysParamsBox")
        self.formLayout_4 = QtWidgets.QFormLayout(self.sysParamsBox)
        self.formLayout_4.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_4.setObjectName("formLayout_4")
        self.nfftLabel = QtWidgets.QLabel(self.sysParamsBox)
        self.nfftLabel.setMinimumSize(QtCore.QSize(150, 0))
        self.nfftLabel.setObjectName("nfftLabel")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.nfftLabel)
        self.nfftEdit = QtWidgets.QLineEdit(self.sysParamsBox)
        self.nfftEdit.setObjectName("nfftEdit")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.nfftEdit)
        self.groupSpecs.raise_()
        self.responseBox.raise_()
        self.sysParamsBox.raise_()
        self.horizontalLayout.addWidget(self.quickFrame)
        self.stackedWindows.addWidget(self.classic)
        self.modern = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.modern.sizePolicy().hasHeightForWidth())
        self.modern.setSizePolicy(sizePolicy)
        self.modern.setObjectName("modern")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.modern)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.splitter_3 = QtWidgets.QSplitter(self.modern)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitter_3.sizePolicy().hasHeightForWidth())
        self.splitter_3.setSizePolicy(sizePolicy)
        self.splitter_3.setOrientation(QtCore.Qt.Vertical)
        self.splitter_3.setObjectName("splitter_3")
        self.splitter_2 = QtWidgets.QSplitter(self.splitter_3)
        self.splitter_2.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_2.setObjectName("splitter_2")
        self.mfreqTabgroup = QtWidgets.QTabWidget(self.splitter_2)
        self.mfreqTabgroup.setTabsClosable(False)
        self.mfreqTabgroup.setObjectName("mfreqTabgroup")
        self.mfreqTab = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mfreqTab.sizePolicy().hasHeightForWidth())
        self.mfreqTab.setSizePolicy(sizePolicy)
        self.mfreqTab.setObjectName("mfreqTab")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.mfreqTab)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.mfreqPlot = GrFilterPlotWidget(self.mfreqTab)
        self.mfreqPlot.setObjectName("mfreqPlot")
        self.horizontalLayout_2.addWidget(self.mfreqPlot)
        self.mfgroupBox = QtWidgets.QGroupBox(self.mfreqTab)
        self.mfgroupBox.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.mfgroupBox.setTitle("")
        self.mfgroupBox.setFlat(False)
        self.mfgroupBox.setCheckable(False)
        self.mfgroupBox.setObjectName("mfgroupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.mfgroupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.mfmagPush = QtWidgets.QToolButton(self.mfgroupBox)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/mag_response.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mfmagPush.setIcon(icon4)
        self.mfmagPush.setIconSize(QtCore.QSize(16, 16))
        self.mfmagPush.setCheckable(False)
        self.mfmagPush.setObjectName("mfmagPush")
        self.verticalLayout_2.addWidget(self.mfmagPush)
        self.mfphasePush = QtWidgets.QToolButton(self.mfgroupBox)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/phase_response.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mfphasePush.setIcon(icon5)
        self.mfphasePush.setIconSize(QtCore.QSize(16, 16))
        self.mfphasePush.setCheckable(False)
        self.mfphasePush.setObjectName("mfphasePush")
        self.verticalLayout_2.addWidget(self.mfphasePush)
        self.mfgpdlyPush = QtWidgets.QToolButton(self.mfgroupBox)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/group_delay.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mfgpdlyPush.setIcon(icon6)
        self.mfgpdlyPush.setIconSize(QtCore.QSize(16, 16))
        self.mfgpdlyPush.setCheckable(False)
        self.mfgpdlyPush.setObjectName("mfgpdlyPush")
        self.verticalLayout_2.addWidget(self.mfgpdlyPush)
        self.mfphdlyPush = QtWidgets.QToolButton(self.mfgroupBox)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/phase_delay.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mfphdlyPush.setIcon(icon7)
        self.mfphdlyPush.setIconSize(QtCore.QSize(16, 16))
        self.mfphdlyPush.setCheckable(False)
        self.mfphdlyPush.setObjectName("mfphdlyPush")
        self.verticalLayout_2.addWidget(self.mfphdlyPush)
        self.mfoverlayPush = QtWidgets.QToolButton(self.mfgroupBox)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/overlay.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mfoverlayPush.setIcon(icon8)
        self.mfoverlayPush.setIconSize(QtCore.QSize(16, 16))
        self.mfoverlayPush.setCheckable(True)
        self.mfoverlayPush.setObjectName("mfoverlayPush")
        self.verticalLayout_2.addWidget(self.mfoverlayPush)
        self.horizontalLayout_2.addWidget(self.mfgroupBox)
        self.mfreqTabgroup.addTab(self.mfreqTab, "")
        self.mtimeTabgroup = QtWidgets.QTabWidget(self.splitter_2)
        self.mtimeTabgroup.setObjectName("mtimeTabgroup")
        self.mtimeTab = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mtimeTab.sizePolicy().hasHeightForWidth())
        self.mtimeTab.setSizePolicy(sizePolicy)
        self.mtimeTab.setObjectName("mtimeTab")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.mtimeTab)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.mtimePlot = GrFilterPlotWidget(self.mtimeTab)
        self.mtimePlot.setObjectName("mtimePlot")
        self.horizontalLayout_3.addWidget(self.mtimePlot)
        self.mtgroupBox = QtWidgets.QGroupBox(self.mtimeTab)
        self.mtgroupBox.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.mtgroupBox.setTitle("")
        self.mtgroupBox.setFlat(False)
        self.mtgroupBox.setCheckable(False)
        self.mtgroupBox.setObjectName("mtgroupBox")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.mtgroupBox)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.mttapsPush = QtWidgets.QToolButton(self.mtgroupBox)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/filtr_taps.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mttapsPush.setIcon(icon9)
        self.mttapsPush.setIconSize(QtCore.QSize(16, 16))
        self.mttapsPush.setCheckable(False)
        self.mttapsPush.setObjectName("mttapsPush")
        self.verticalLayout_5.addWidget(self.mttapsPush)
        self.mtstepPush = QtWidgets.QToolButton(self.mtgroupBox)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/step_response.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mtstepPush.setIcon(icon10)
        self.mtstepPush.setIconSize(QtCore.QSize(16, 16))
        self.mtstepPush.setCheckable(False)
        self.mtstepPush.setObjectName("mtstepPush")
        self.verticalLayout_5.addWidget(self.mtstepPush)
        self.mtimpPush = QtWidgets.QToolButton(self.mtgroupBox)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/impulse.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.mtimpPush.setIcon(icon11)
        self.mtimpPush.setIconSize(QtCore.QSize(16, 16))
        self.mtimpPush.setCheckable(False)
        self.mtimpPush.setObjectName("mtimpPush")
        self.verticalLayout_5.addWidget(self.mtimpPush)
        self.horizontalLayout_3.addWidget(self.mtgroupBox)
        self.mtimeTabgroup.addTab(self.mtimeTab, "")
        self.mfilterspecView = QtWidgets.QTabWidget(self.splitter_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mfilterspecView.sizePolicy().hasHeightForWidth())
        self.mfilterspecView.setSizePolicy(sizePolicy)
        self.mfilterspecView.setMinimumSize(QtCore.QSize(0, 100))
        self.mfilterspecView.setBaseSize(QtCore.QSize(0, 100))
        self.mfilterspecView.setDocumentMode(False)
        self.mfilterspecView.setTabsClosable(False)
        self.mfilterspecView.setObjectName("mfilterspecView")
        self.mbandDiagram = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mbandDiagram.sizePolicy().hasHeightForWidth())
        self.mbandDiagram.setSizePolicy(sizePolicy)
        self.mbandDiagram.setObjectName("mbandDiagram")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.mbandDiagram)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.mbandView = BandGraphicsView(self.mbandDiagram)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.mbandView.sizePolicy().hasHeightForWidth())
        self.mbandView.setSizePolicy(sizePolicy)
        self.mbandView.setMinimumSize(QtCore.QSize(525, 249))
        self.mbandView.setObjectName("mbandView")
        self.horizontalLayout_15.addWidget(self.mbandView)
        self.mfilterspecView.addTab(self.mbandDiagram, "")
        self.mpoleZero = QtWidgets.QWidget()
        self.mpoleZero.setAutoFillBackground(False)
        self.mpoleZero.setObjectName("mpoleZero")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.mpoleZero)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.mpzgroupBox = QtWidgets.QGroupBox(self.mpoleZero)
        self.mpzgroupBox.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.mpzgroupBox.setTitle("")
        self.mpzgroupBox.setFlat(False)
        self.mpzgroupBox.setCheckable(False)
        self.mpzgroupBox.setObjectName("mpzgroupBox")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.mpzgroupBox)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.maddzeroPush = QtWidgets.QToolButton(self.mpzgroupBox)
        self.maddzeroPush.setIcon(icon)
        self.maddzeroPush.setCheckable(True)
        self.maddzeroPush.setObjectName("maddzeroPush")
        self.verticalLayout_4.addWidget(self.maddzeroPush)
        self.maddpolePush = QtWidgets.QToolButton(self.mpzgroupBox)
        self.maddpolePush.setIcon(icon1)
        self.maddpolePush.setCheckable(True)
        self.maddpolePush.setObjectName("maddpolePush")
        self.verticalLayout_4.addWidget(self.maddpolePush)
        self.mdelPush = QtWidgets.QToolButton(self.mpzgroupBox)
        self.mdelPush.setIcon(icon2)
        self.mdelPush.setCheckable(True)
        self.mdelPush.setObjectName("mdelPush")
        self.verticalLayout_4.addWidget(self.mdelPush)
        self.mconjPush = QtWidgets.QToolButton(self.mpzgroupBox)
        self.mconjPush.setIcon(icon3)
        self.mconjPush.setIconSize(QtCore.QSize(16, 16))
        self.mconjPush.setCheckable(True)
        self.mconjPush.setObjectName("mconjPush")
        self.verticalLayout_4.addWidget(self.mconjPush)
        self.gridLayout_3.addWidget(self.mpzgroupBox, 0, 2, 1, 1)
        self.mpzstatusBar = QtWidgets.QStatusBar(self.mpoleZero)
        self.mpzstatusBar.setObjectName("mpzstatusBar")
        self.gridLayout_3.addWidget(self.mpzstatusBar, 1, 0, 1, 3)
        self.mpzPlot = PzPlot(self.mpoleZero)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mpzPlot.sizePolicy().hasHeightForWidth())
        self.mpzPlot.setSizePolicy(sizePolicy)
        self.mpzPlot.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.mpzPlot.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.mpzPlot.setLineWidth(1)
        self.mpzPlot.setInteractive(True)
        self.mpzPlot.setObjectName("mpzPlot")
        self.gridLayout_3.addWidget(self.mpzPlot, 0, 1, 1, 1)
        self.mfilterspecView.addTab(self.mpoleZero, "")
        self.mfcTab = QtWidgets.QWidget()
        self.mfcTab.setObjectName("mfcTab")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.mfcTab)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.mfilterCoeff = QtWidgets.QTextBrowser(self.mfcTab)
        self.mfilterCoeff.setObjectName("mfilterCoeff")
        self.horizontalLayout_4.addWidget(self.mfilterCoeff)
        self.mfilterspecView.addTab(self.mfcTab, "")
        self.horizontalLayout_5.addWidget(self.splitter_3)
        self.stackedWindows.addWidget(self.modern)
        self.gridLayout.addWidget(self.stackedWindows, 0, 1, 1, 1)
        self.filterFrame = QtWidgets.QFrame(self.centralwidget)
        self.filterFrame.setMinimumSize(QtCore.QSize(300, 0))
        self.filterFrame.setMaximumSize(QtCore.QSize(300, 16777215))
        self.filterFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.filterFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.filterFrame.setObjectName("filterFrame")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.filterFrame)
        self.verticalLayout.setObjectName("verticalLayout")
        self.fselectComboBox = QtWidgets.QComboBox(self.filterFrame)
        self.fselectComboBox.setEnabled(True)
        self.fselectComboBox.setObjectName("fselectComboBox")
        self.fselectComboBox.addItem("")
        self.fselectComboBox.addItem("")
        self.verticalLayout.addWidget(self.fselectComboBox)
        self.filterTypeComboBox = QtWidgets.QComboBox(self.filterFrame)
        self.filterTypeComboBox.setObjectName("filterTypeComboBox")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.filterTypeComboBox.addItem("")
        self.verticalLayout.addWidget(self.filterTypeComboBox)
        self.iirfilterBandComboBox = QtWidgets.QComboBox(self.filterFrame)
        self.iirfilterBandComboBox.setObjectName("iirfilterBandComboBox")
        self.iirfilterBandComboBox.addItem("")
        self.iirfilterBandComboBox.addItem("")
        self.iirfilterBandComboBox.addItem("")
        self.iirfilterBandComboBox.addItem("")
        self.verticalLayout.addWidget(self.iirfilterBandComboBox)
        self.adComboBox = QtWidgets.QComboBox(self.filterFrame)
        self.adComboBox.setObjectName("adComboBox")
        self.adComboBox.addItem("")
        self.adComboBox.addItem("")
        self.verticalLayout.addWidget(self.adComboBox)
        self.filterDesignTypeComboBox = QtWidgets.QComboBox(self.filterFrame)
        self.filterDesignTypeComboBox.setObjectName("filterDesignTypeComboBox")
        self.filterDesignTypeComboBox.addItem("")
        self.filterDesignTypeComboBox.addItem("")
        self.filterDesignTypeComboBox.addItem("")
        self.filterDesignTypeComboBox.addItem("")
        self.filterDesignTypeComboBox.addItem("")
        self.filterDesignTypeComboBox.addItem("")
        self.filterDesignTypeComboBox.addItem("")
        self.verticalLayout.addWidget(self.filterDesignTypeComboBox)
        self.iirfilterTypeComboBox = QtWidgets.QComboBox(self.filterFrame)
        self.iirfilterTypeComboBox.setObjectName("iirfilterTypeComboBox")
        self.iirfilterTypeComboBox.addItem("")
        self.iirfilterTypeComboBox.addItem("")
        self.iirfilterTypeComboBox.addItem("")
        self.iirfilterTypeComboBox.addItem("")
        self.iirfilterTypeComboBox.addItem("")
        self.verticalLayout.addWidget(self.iirfilterTypeComboBox)
        self.globalParamsBox = QtWidgets.QGroupBox(self.filterFrame)
        self.globalParamsBox.setTitle("")
        self.globalParamsBox.setObjectName("globalParamsBox")
        self.formLayout_12 = QtWidgets.QFormLayout(self.globalParamsBox)
        self.formLayout_12.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_12.setObjectName("formLayout_12")
        self.sampleRateLabel = QtWidgets.QLabel(self.globalParamsBox)
        self.sampleRateLabel.setMaximumSize(QtCore.QSize(16777215, 30))
        self.sampleRateLabel.setObjectName("sampleRateLabel")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.sampleRateLabel)
        self.sampleRateEdit = QtWidgets.QLineEdit(self.globalParamsBox)
        self.sampleRateEdit.setMaximumSize(QtCore.QSize(16777215, 30))
        self.sampleRateEdit.setObjectName("sampleRateEdit")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.sampleRateEdit)
        self.filterGainLabel = QtWidgets.QLabel(self.globalParamsBox)
        self.filterGainLabel.setObjectName("filterGainLabel")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.filterGainLabel)
        self.filterGainEdit = QtWidgets.QLineEdit(self.globalParamsBox)
        self.filterGainEdit.setObjectName("filterGainEdit")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.filterGainEdit)
        self.verticalLayout.addWidget(self.globalParamsBox)
        self.filterTypeWidget = QtWidgets.QStackedWidget(self.filterFrame)
        self.filterTypeWidget.setObjectName("filterTypeWidget")
        self.firlpfPage = QtWidgets.QWidget()
        self.firlpfPage.setObjectName("firlpfPage")
        self.formLayout = QtWidgets.QFormLayout(self.firlpfPage)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.endofLpfPassBandLabel = QtWidgets.QLabel(self.firlpfPage)
        self.endofLpfPassBandLabel.setObjectName("endofLpfPassBandLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.endofLpfPassBandLabel)
        self.endofLpfPassBandEdit = QtWidgets.QLineEdit(self.firlpfPage)
        self.endofLpfPassBandEdit.setObjectName("endofLpfPassBandEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.endofLpfPassBandEdit)
        self.startofLpfStopBandLabel = QtWidgets.QLabel(self.firlpfPage)
        self.startofLpfStopBandLabel.setObjectName("startofLpfStopBandLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.startofLpfStopBandLabel)
        self.startofLpfStopBandEdit = QtWidgets.QLineEdit(self.firlpfPage)
        self.startofLpfStopBandEdit.setObjectName("startofLpfStopBandEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.startofLpfStopBandEdit)
        self.lpfStopBandAttenLabel = QtWidgets.QLabel(self.firlpfPage)
        self.lpfStopBandAttenLabel.setObjectName("lpfStopBandAttenLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.lpfStopBandAttenLabel)
        self.lpfStopBandAttenEdit = QtWidgets.QLineEdit(self.firlpfPage)
        self.lpfStopBandAttenEdit.setObjectName("lpfStopBandAttenEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.lpfStopBandAttenEdit)
        self.lpfPassBandRippleLabel = QtWidgets.QLabel(self.firlpfPage)
        self.lpfPassBandRippleLabel.setObjectName("lpfPassBandRippleLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.lpfPassBandRippleLabel)
        self.lpfPassBandRippleEdit = QtWidgets.QLineEdit(self.firlpfPage)
        self.lpfPassBandRippleEdit.setObjectName("lpfPassBandRippleEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.lpfPassBandRippleEdit)
        self.filterTypeWidget.addWidget(self.firlpfPage)
        self.firbpfPage = QtWidgets.QWidget()
        self.firbpfPage.setObjectName("firbpfPage")
        self.formLayout_2 = QtWidgets.QFormLayout(self.firbpfPage)
        self.formLayout_2.setObjectName("formLayout_2")
        self.startofBpfPassBandLabel = QtWidgets.QLabel(self.firbpfPage)
        self.startofBpfPassBandLabel.setObjectName("startofBpfPassBandLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.startofBpfPassBandLabel)
        self.startofBpfPassBandEdit = QtWidgets.QLineEdit(self.firbpfPage)
        self.startofBpfPassBandEdit.setObjectName("startofBpfPassBandEdit")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.startofBpfPassBandEdit)
        self.endofBpfPassBandLabel = QtWidgets.QLabel(self.firbpfPage)
        self.endofBpfPassBandLabel.setObjectName("endofBpfPassBandLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.endofBpfPassBandLabel)
        self.endofBpfPassBandEdit = QtWidgets.QLineEdit(self.firbpfPage)
        self.endofBpfPassBandEdit.setObjectName("endofBpfPassBandEdit")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.endofBpfPassBandEdit)
        self.bpfStopBandAttenEdit = QtWidgets.QLineEdit(self.firbpfPage)
        self.bpfStopBandAttenEdit.setObjectName("bpfStopBandAttenEdit")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.bpfStopBandAttenEdit)
        self.bpfStopBandAttenLabel = QtWidgets.QLabel(self.firbpfPage)
        self.bpfStopBandAttenLabel.setObjectName("bpfStopBandAttenLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.bpfStopBandAttenLabel)
        self.bpfTransitionLabel = QtWidgets.QLabel(self.firbpfPage)
        self.bpfTransitionLabel.setObjectName("bpfTransitionLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.bpfTransitionLabel)
        self.bpfTransitionEdit = QtWidgets.QLineEdit(self.firbpfPage)
        self.bpfTransitionEdit.setObjectName("bpfTransitionEdit")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.bpfTransitionEdit)
        self.bpfPassBandRippleEdit = QtWidgets.QLineEdit(self.firbpfPage)
        self.bpfPassBandRippleEdit.setObjectName("bpfPassBandRippleEdit")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.bpfPassBandRippleEdit)
        self.bpfPassBandRippleLabel = QtWidgets.QLabel(self.firbpfPage)
        self.bpfPassBandRippleLabel.setObjectName("bpfPassBandRippleLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.bpfPassBandRippleLabel)
        self.filterTypeWidget.addWidget(self.firbpfPage)
        self.firbnfPage = QtWidgets.QWidget()
        self.firbnfPage.setObjectName("firbnfPage")
        self.formLayout_5 = QtWidgets.QFormLayout(self.firbnfPage)
        self.formLayout_5.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_5.setObjectName("formLayout_5")
        self.startofBnfStopBandLabel = QtWidgets.QLabel(self.firbnfPage)
        self.startofBnfStopBandLabel.setObjectName("startofBnfStopBandLabel")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.startofBnfStopBandLabel)
        self.startofBnfStopBandEdit = QtWidgets.QLineEdit(self.firbnfPage)
        self.startofBnfStopBandEdit.setObjectName("startofBnfStopBandEdit")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.startofBnfStopBandEdit)
        self.endofBnfStopBandLabel = QtWidgets.QLabel(self.firbnfPage)
        self.endofBnfStopBandLabel.setObjectName("endofBnfStopBandLabel")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.endofBnfStopBandLabel)
        self.endofBnfStopBandEdit = QtWidgets.QLineEdit(self.firbnfPage)
        self.endofBnfStopBandEdit.setObjectName("endofBnfStopBandEdit")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.endofBnfStopBandEdit)
        self.bnfTransitionLabel = QtWidgets.QLabel(self.firbnfPage)
        self.bnfTransitionLabel.setObjectName("bnfTransitionLabel")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.bnfTransitionLabel)
        self.bnfTransitionEdit = QtWidgets.QLineEdit(self.firbnfPage)
        self.bnfTransitionEdit.setObjectName("bnfTransitionEdit")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.bnfTransitionEdit)
        self.bnfStopBandAttenLabel = QtWidgets.QLabel(self.firbnfPage)
        self.bnfStopBandAttenLabel.setObjectName("bnfStopBandAttenLabel")
        self.formLayout_5.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.bnfStopBandAttenLabel)
        self.bnfStopBandAttenEdit = QtWidgets.QLineEdit(self.firbnfPage)
        self.bnfStopBandAttenEdit.setObjectName("bnfStopBandAttenEdit")
        self.formLayout_5.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.bnfStopBandAttenEdit)
        self.bnfPassBandRippleLabel = QtWidgets.QLabel(self.firbnfPage)
        self.bnfPassBandRippleLabel.setObjectName("bnfPassBandRippleLabel")
        self.formLayout_5.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.bnfPassBandRippleLabel)
        self.bnfPassBandRippleEdit = QtWidgets.QLineEdit(self.firbnfPage)
        self.bnfPassBandRippleEdit.setObjectName("bnfPassBandRippleEdit")
        self.formLayout_5.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.bnfPassBandRippleEdit)
        self.filterTypeWidget.addWidget(self.firbnfPage)
        self.firhpfPage = QtWidgets.QWidget()
        self.firhpfPage.setObjectName("firhpfPage")
        self.formLayout_3 = QtWidgets.QFormLayout(self.firhpfPage)
        self.formLayout_3.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_3.setObjectName("formLayout_3")
        self.endofHpfStopBandLabel = QtWidgets.QLabel(self.firhpfPage)
        self.endofHpfStopBandLabel.setObjectName("endofHpfStopBandLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.endofHpfStopBandLabel)
        self.endofHpfStopBandEdit = QtWidgets.QLineEdit(self.firhpfPage)
        self.endofHpfStopBandEdit.setObjectName("endofHpfStopBandEdit")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.endofHpfStopBandEdit)
        self.startofHpfPassBandLabel = QtWidgets.QLabel(self.firhpfPage)
        self.startofHpfPassBandLabel.setObjectName("startofHpfPassBandLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.startofHpfPassBandLabel)
        self.startofHpfPassBandEdit = QtWidgets.QLineEdit(self.firhpfPage)
        self.startofHpfPassBandEdit.setObjectName("startofHpfPassBandEdit")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.startofHpfPassBandEdit)
        self.hpfStopBandAttenLabel = QtWidgets.QLabel(self.firhpfPage)
        self.hpfStopBandAttenLabel.setObjectName("hpfStopBandAttenLabel")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.hpfStopBandAttenLabel)
        self.hpfStopBandAttenEdit = QtWidgets.QLineEdit(self.firhpfPage)
        self.hpfStopBandAttenEdit.setObjectName("hpfStopBandAttenEdit")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.hpfStopBandAttenEdit)
        self.hpfPassBandRippleLabel = QtWidgets.QLabel(self.firhpfPage)
        self.hpfPassBandRippleLabel.setObjectName("hpfPassBandRippleLabel")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.hpfPassBandRippleLabel)
        self.hpfPassBandRippleEdit = QtWidgets.QLineEdit(self.firhpfPage)
        self.hpfPassBandRippleEdit.setObjectName("hpfPassBandRippleEdit")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.hpfPassBandRippleEdit)
        self.filterTypeWidget.addWidget(self.firhpfPage)
        self.rrcPage = QtWidgets.QWidget()
        self.rrcPage.setObjectName("rrcPage")
        self.formLayout_6 = QtWidgets.QFormLayout(self.rrcPage)
        self.formLayout_6.setObjectName("formLayout_6")
        self.rrcSymbolRateLabel = QtWidgets.QLabel(self.rrcPage)
        self.rrcSymbolRateLabel.setObjectName("rrcSymbolRateLabel")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.rrcSymbolRateLabel)
        self.rrcAlphaLabel = QtWidgets.QLabel(self.rrcPage)
        self.rrcAlphaLabel.setObjectName("rrcAlphaLabel")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.rrcAlphaLabel)
        self.rrcNumTapsLabel = QtWidgets.QLabel(self.rrcPage)
        self.rrcNumTapsLabel.setObjectName("rrcNumTapsLabel")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.rrcNumTapsLabel)
        self.rrcSymbolRateEdit = QtWidgets.QLineEdit(self.rrcPage)
        self.rrcSymbolRateEdit.setObjectName("rrcSymbolRateEdit")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.rrcSymbolRateEdit)
        self.rrcAlphaEdit = QtWidgets.QLineEdit(self.rrcPage)
        self.rrcAlphaEdit.setObjectName("rrcAlphaEdit")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.rrcAlphaEdit)
        self.rrcNumTapsEdit = QtWidgets.QLineEdit(self.rrcPage)
        self.rrcNumTapsEdit.setObjectName("rrcNumTapsEdit")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.rrcNumTapsEdit)
        self.filterTypeWidget.addWidget(self.rrcPage)
        self.gausPage = QtWidgets.QWidget()
        self.gausPage.setObjectName("gausPage")
        self.formLayout_7 = QtWidgets.QFormLayout(self.gausPage)
        self.formLayout_7.setObjectName("formLayout_7")
        self.gausSymbolRateLabel = QtWidgets.QLabel(self.gausPage)
        self.gausSymbolRateLabel.setObjectName("gausSymbolRateLabel")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.gausSymbolRateLabel)
        self.gausSymbolRateEdit = QtWidgets.QLineEdit(self.gausPage)
        self.gausSymbolRateEdit.setObjectName("gausSymbolRateEdit")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.gausSymbolRateEdit)
        self.gausBTLabel = QtWidgets.QLabel(self.gausPage)
        self.gausBTLabel.setObjectName("gausBTLabel")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.gausBTLabel)
        self.gausBTEdit = QtWidgets.QLineEdit(self.gausPage)
        self.gausBTEdit.setObjectName("gausBTEdit")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.gausBTEdit)
        self.gausNumTapsLabel = QtWidgets.QLabel(self.gausPage)
        self.gausNumTapsLabel.setObjectName("gausNumTapsLabel")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.gausNumTapsLabel)
        self.gausNumTapsEdit = QtWidgets.QLineEdit(self.gausPage)
        self.gausNumTapsEdit.setObjectName("gausNumTapsEdit")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.gausNumTapsEdit)
        self.filterTypeWidget.addWidget(self.gausPage)
        self.iirlpfPage = QtWidgets.QWidget()
        self.iirlpfPage.setObjectName("iirlpfPage")
        self.formLayout_15 = QtWidgets.QFormLayout(self.iirlpfPage)
        self.formLayout_15.setObjectName("formLayout_15")
        self.iirendofLpfPassBandLabel = QtWidgets.QLabel(self.iirlpfPage)
        self.iirendofLpfPassBandLabel.setObjectName("iirendofLpfPassBandLabel")
        self.formLayout_15.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.iirendofLpfPassBandLabel)
        self.iirendofLpfPassBandEdit = QtWidgets.QLineEdit(self.iirlpfPage)
        self.iirendofLpfPassBandEdit.setObjectName("iirendofLpfPassBandEdit")
        self.formLayout_15.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.iirendofLpfPassBandEdit)
        self.iirstartofLpfStopBandLabel = QtWidgets.QLabel(self.iirlpfPage)
        self.iirstartofLpfStopBandLabel.setObjectName("iirstartofLpfStopBandLabel")
        self.formLayout_15.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.iirstartofLpfStopBandLabel)
        self.iirstartofLpfStopBandEdit = QtWidgets.QLineEdit(self.iirlpfPage)
        self.iirstartofLpfStopBandEdit.setObjectName("iirstartofLpfStopBandEdit")
        self.formLayout_15.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.iirstartofLpfStopBandEdit)
        self.iirLpfPassBandAttenLabel = QtWidgets.QLabel(self.iirlpfPage)
        self.iirLpfPassBandAttenLabel.setObjectName("iirLpfPassBandAttenLabel")
        self.formLayout_15.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.iirLpfPassBandAttenLabel)
        self.iirLpfPassBandAttenEdit = QtWidgets.QLineEdit(self.iirlpfPage)
        self.iirLpfPassBandAttenEdit.setObjectName("iirLpfPassBandAttenEdit")
        self.formLayout_15.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.iirLpfPassBandAttenEdit)
        self.iirLpfStopBandRippleLabel = QtWidgets.QLabel(self.iirlpfPage)
        self.iirLpfStopBandRippleLabel.setObjectName("iirLpfStopBandRippleLabel")
        self.formLayout_15.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.iirLpfStopBandRippleLabel)
        self.iirLpfStopBandRippleEdit = QtWidgets.QLineEdit(self.iirlpfPage)
        self.iirLpfStopBandRippleEdit.setObjectName("iirLpfStopBandRippleEdit")
        self.formLayout_15.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.iirLpfStopBandRippleEdit)
        self.filterTypeWidget.addWidget(self.iirlpfPage)
        self.iirhpfPage = QtWidgets.QWidget()
        self.iirhpfPage.setObjectName("iirhpfPage")
        self.formLayout_9 = QtWidgets.QFormLayout(self.iirhpfPage)
        self.formLayout_9.setObjectName("formLayout_9")
        self.iirendofHpfStopBandLabel = QtWidgets.QLabel(self.iirhpfPage)
        self.iirendofHpfStopBandLabel.setObjectName("iirendofHpfStopBandLabel")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.iirendofHpfStopBandLabel)
        self.iirendofHpfStopBandEdit = QtWidgets.QLineEdit(self.iirhpfPage)
        self.iirendofHpfStopBandEdit.setObjectName("iirendofHpfStopBandEdit")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.iirendofHpfStopBandEdit)
        self.iirstartofHpfPassBandLabel = QtWidgets.QLabel(self.iirhpfPage)
        self.iirstartofHpfPassBandLabel.setObjectName("iirstartofHpfPassBandLabel")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.iirstartofHpfPassBandLabel)
        self.iirstartofHpfPassBandEdit = QtWidgets.QLineEdit(self.iirhpfPage)
        self.iirstartofHpfPassBandEdit.setObjectName("iirstartofHpfPassBandEdit")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.iirstartofHpfPassBandEdit)
        self.iirHpfPassBandAttenLabel = QtWidgets.QLabel(self.iirhpfPage)
        self.iirHpfPassBandAttenLabel.setObjectName("iirHpfPassBandAttenLabel")
        self.formLayout_9.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.iirHpfPassBandAttenLabel)
        self.iirHpfPassBandAttenEdit = QtWidgets.QLineEdit(self.iirhpfPage)
        self.iirHpfPassBandAttenEdit.setObjectName("iirHpfPassBandAttenEdit")
        self.formLayout_9.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.iirHpfPassBandAttenEdit)
        self.iirHpfStopBandRippleLabel = QtWidgets.QLabel(self.iirhpfPage)
        self.iirHpfStopBandRippleLabel.setObjectName("iirHpfStopBandRippleLabel")
        self.formLayout_9.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.iirHpfStopBandRippleLabel)
        self.iirHpfStopBandRippleEdit = QtWidgets.QLineEdit(self.iirhpfPage)
        self.iirHpfStopBandRippleEdit.setObjectName("iirHpfStopBandRippleEdit")
        self.formLayout_9.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.iirHpfStopBandRippleEdit)
        self.filterTypeWidget.addWidget(self.iirhpfPage)
        self.iirbpfPage = QtWidgets.QWidget()
        self.iirbpfPage.setObjectName("iirbpfPage")
        self.formLayout_10 = QtWidgets.QFormLayout(self.iirbpfPage)
        self.formLayout_10.setObjectName("formLayout_10")
        self.iirendofBpfStopBandLabel1 = QtWidgets.QLabel(self.iirbpfPage)
        self.iirendofBpfStopBandLabel1.setObjectName("iirendofBpfStopBandLabel1")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.iirendofBpfStopBandLabel1)
        self.iirendofBpfStopBandEdit1 = QtWidgets.QLineEdit(self.iirbpfPage)
        self.iirendofBpfStopBandEdit1.setObjectName("iirendofBpfStopBandEdit1")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.iirendofBpfStopBandEdit1)
        self.iirstartofBpfPassBandLabel = QtWidgets.QLabel(self.iirbpfPage)
        self.iirstartofBpfPassBandLabel.setObjectName("iirstartofBpfPassBandLabel")
        self.formLayout_10.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.iirstartofBpfPassBandLabel)
        self.iirstartofBpfPassBandEdit = QtWidgets.QLineEdit(self.iirbpfPage)
        self.iirstartofBpfPassBandEdit.setObjectName("iirstartofBpfPassBandEdit")
        self.formLayout_10.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.iirstartofBpfPassBandEdit)
        self.iirendofBpfPassBandLabel = QtWidgets.QLabel(self.iirbpfPage)
        self.iirendofBpfPassBandLabel.setObjectName("iirendofBpfPassBandLabel")
        self.formLayout_10.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.iirendofBpfPassBandLabel)
        self.iirendofBpfPassBandEdit = QtWidgets.QLineEdit(self.iirbpfPage)
        self.iirendofBpfPassBandEdit.setObjectName("iirendofBpfPassBandEdit")
        self.formLayout_10.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.iirendofBpfPassBandEdit)
        self.iirstartofBpfStopBandLabel2 = QtWidgets.QLabel(self.iirbpfPage)
        self.iirstartofBpfStopBandLabel2.setObjectName("iirstartofBpfStopBandLabel2")
        self.formLayout_10.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.iirstartofBpfStopBandLabel2)
        self.iirstartofBpfStopBandEdit2 = QtWidgets.QLineEdit(self.iirbpfPage)
        self.iirstartofBpfStopBandEdit2.setObjectName("iirstartofBpfStopBandEdit2")
        self.formLayout_10.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.iirstartofBpfStopBandEdit2)
        self.iirBpfPassBandAttenLabel = QtWidgets.QLabel(self.iirbpfPage)
        self.iirBpfPassBandAttenLabel.setObjectName("iirBpfPassBandAttenLabel")
        self.formLayout_10.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.iirBpfPassBandAttenLabel)
        self.iirBpfPassBandAttenEdit = QtWidgets.QLineEdit(self.iirbpfPage)
        self.iirBpfPassBandAttenEdit.setObjectName("iirBpfPassBandAttenEdit")
        self.formLayout_10.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.iirBpfPassBandAttenEdit)
        self.iirBpfStopBandRippleLabel = QtWidgets.QLabel(self.iirbpfPage)
        self.iirBpfStopBandRippleLabel.setObjectName("iirBpfStopBandRippleLabel")
        self.formLayout_10.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.iirBpfStopBandRippleLabel)
        self.iirBpfStopBandRippleEdit = QtWidgets.QLineEdit(self.iirbpfPage)
        self.iirBpfStopBandRippleEdit.setObjectName("iirBpfStopBandRippleEdit")
        self.formLayout_10.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.iirBpfStopBandRippleEdit)
        self.filterTypeWidget.addWidget(self.iirbpfPage)
        self.iirbsfPage = QtWidgets.QWidget()
        self.iirbsfPage.setObjectName("iirbsfPage")
        self.formLayout_11 = QtWidgets.QFormLayout(self.iirbsfPage)
        self.formLayout_11.setObjectName("formLayout_11")
        self.iirendofBsfPassBandLabel1 = QtWidgets.QLabel(self.iirbsfPage)
        self.iirendofBsfPassBandLabel1.setObjectName("iirendofBsfPassBandLabel1")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.iirendofBsfPassBandLabel1)
        self.iirendofBsfPassBandEdit1 = QtWidgets.QLineEdit(self.iirbsfPage)
        self.iirendofBsfPassBandEdit1.setObjectName("iirendofBsfPassBandEdit1")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.iirendofBsfPassBandEdit1)
        self.iirstartofBsfStopBandLabel = QtWidgets.QLabel(self.iirbsfPage)
        self.iirstartofBsfStopBandLabel.setObjectName("iirstartofBsfStopBandLabel")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.iirstartofBsfStopBandLabel)
        self.iirstartofBsfStopBandEdit = QtWidgets.QLineEdit(self.iirbsfPage)
        self.iirstartofBsfStopBandEdit.setObjectName("iirstartofBsfStopBandEdit")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.iirstartofBsfStopBandEdit)
        self.iirendofBsfStopBandLabel = QtWidgets.QLabel(self.iirbsfPage)
        self.iirendofBsfStopBandLabel.setObjectName("iirendofBsfStopBandLabel")
        self.formLayout_11.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.iirendofBsfStopBandLabel)
        self.iirendofBsfStopBandEdit = QtWidgets.QLineEdit(self.iirbsfPage)
        self.iirendofBsfStopBandEdit.setObjectName("iirendofBsfStopBandEdit")
        self.formLayout_11.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.iirendofBsfStopBandEdit)
        self.iirstartofBsfPassBandLabel2 = QtWidgets.QLabel(self.iirbsfPage)
        self.iirstartofBsfPassBandLabel2.setObjectName("iirstartofBsfPassBandLabel2")
        self.formLayout_11.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.iirstartofBsfPassBandLabel2)
        self.iirstartofBsfPassBandEdit2 = QtWidgets.QLineEdit(self.iirbsfPage)
        self.iirstartofBsfPassBandEdit2.setObjectName("iirstartofBsfPassBandEdit2")
        self.formLayout_11.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.iirstartofBsfPassBandEdit2)
        self.iirBsfPassBandAttenLabel = QtWidgets.QLabel(self.iirbsfPage)
        self.iirBsfPassBandAttenLabel.setObjectName("iirBsfPassBandAttenLabel")
        self.formLayout_11.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.iirBsfPassBandAttenLabel)
        self.iirBsfPassBandAttenEdit = QtWidgets.QLineEdit(self.iirbsfPage)
        self.iirBsfPassBandAttenEdit.setObjectName("iirBsfPassBandAttenEdit")
        self.formLayout_11.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.iirBsfPassBandAttenEdit)
        self.iirBsfStopBandRippleLabel = QtWidgets.QLabel(self.iirbsfPage)
        self.iirBsfStopBandRippleLabel.setObjectName("iirBsfStopBandRippleLabel")
        self.formLayout_11.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.iirBsfStopBandRippleLabel)
        self.iirBsfStopBandRippleEdit = QtWidgets.QLineEdit(self.iirbsfPage)
        self.iirBsfStopBandRippleEdit.setObjectName("iirBsfStopBandRippleEdit")
        self.formLayout_11.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.iirBsfStopBandRippleEdit)
        self.filterTypeWidget.addWidget(self.iirbsfPage)
        self.iirbesselPage = QtWidgets.QWidget()
        self.iirbesselPage.setObjectName("iirbesselPage")
        self.formLayout_13 = QtWidgets.QFormLayout(self.iirbesselPage)
        self.formLayout_13.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_13.setObjectName("formLayout_13")
        self.besselordLabel = QtWidgets.QLabel(self.iirbesselPage)
        self.besselordLabel.setObjectName("besselordLabel")
        self.formLayout_13.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.besselordLabel)
        self.besselordEdit = QtWidgets.QLineEdit(self.iirbesselPage)
        self.besselordEdit.setObjectName("besselordEdit")
        self.formLayout_13.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.besselordEdit)
        self.iirbesselcritLabel1 = QtWidgets.QLabel(self.iirbesselPage)
        self.iirbesselcritLabel1.setObjectName("iirbesselcritLabel1")
        self.formLayout_13.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.iirbesselcritLabel1)
        self.iirbesselcritEdit1 = QtWidgets.QLineEdit(self.iirbesselPage)
        self.iirbesselcritEdit1.setObjectName("iirbesselcritEdit1")
        self.formLayout_13.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.iirbesselcritEdit1)
        self.iirbesselcritEdit2 = QtWidgets.QLineEdit(self.iirbesselPage)
        self.iirbesselcritEdit2.setObjectName("iirbesselcritEdit2")
        self.formLayout_13.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.iirbesselcritEdit2)
        self.iirbesselcritLabel2 = QtWidgets.QLabel(self.iirbesselPage)
        self.iirbesselcritLabel2.setObjectName("iirbesselcritLabel2")
        self.formLayout_13.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.iirbesselcritLabel2)
        self.filterTypeWidget.addWidget(self.iirbesselPage)
        self.firhbPage = QtWidgets.QWidget()
        self.firhbPage.setObjectName("firhbPage")
        self.formLayout_14 = QtWidgets.QFormLayout(self.firhbPage)
        self.formLayout_14.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_14.setObjectName("formLayout_14")
        self.firhbordLabel = QtWidgets.QLabel(self.firhbPage)
        self.firhbordLabel.setObjectName("firhbordLabel")
        self.formLayout_14.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.firhbordLabel)
        self.firhbordEdit = QtWidgets.QLineEdit(self.firhbPage)
        self.firhbordEdit.setObjectName("firhbordEdit")
        self.formLayout_14.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.firhbordEdit)
        self.firhbtrEditLabel2 = QtWidgets.QLabel(self.firhbPage)
        self.firhbtrEditLabel2.setObjectName("firhbtrEditLabel2")
        self.formLayout_14.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.firhbtrEditLabel2)
        self.firhbtrEdit = QtWidgets.QLineEdit(self.firhbPage)
        self.firhbtrEdit.setObjectName("firhbtrEdit")
        self.formLayout_14.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.firhbtrEdit)
        self.filterTypeWidget.addWidget(self.firhbPage)
        self.verticalLayout.addWidget(self.filterTypeWidget)
        self.filterPropsBox = QtWidgets.QGroupBox(self.filterFrame)
        self.filterPropsBox.setObjectName("filterPropsBox")
        self.formLayout_8 = QtWidgets.QFormLayout(self.filterPropsBox)
        self.formLayout_8.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_8.setObjectName("formLayout_8")
        self.nTapsLabel = QtWidgets.QLabel(self.filterPropsBox)
        self.nTapsLabel.setMinimumSize(QtCore.QSize(150, 0))
        self.nTapsLabel.setObjectName("nTapsLabel")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.nTapsLabel)
        self.nTapsEdit = QtWidgets.QLabel(self.filterPropsBox)
        self.nTapsEdit.setMaximumSize(QtCore.QSize(100, 16777215))
        self.nTapsEdit.setFrameShape(QtWidgets.QFrame.Box)
        self.nTapsEdit.setFrameShadow(QtWidgets.QFrame.Raised)
        self.nTapsEdit.setText("")
        self.nTapsEdit.setObjectName("nTapsEdit")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.nTapsEdit)
        self.verticalLayout.addWidget(self.filterPropsBox)
        self.designButton = QtWidgets.QPushButton(self.filterFrame)
        self.designButton.setMinimumSize(QtCore.QSize(0, 0))
        self.designButton.setMaximumSize(QtCore.QSize(200, 16777215))
        self.designButton.setAutoDefault(True)
        self.designButton.setDefault(True)
        self.designButton.setObjectName("designButton")
        self.verticalLayout.addWidget(self.designButton)
        self.gridLayout.addWidget(self.filterFrame, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1141, 20))
        self.menubar.setObjectName("menubar")
        self.menu_File = QtWidgets.QMenu(self.menubar)
        self.menu_File.setObjectName("menu_File")
        self.menu_Analysis = QtWidgets.QMenu(self.menubar)
        self.menu_Analysis.setObjectName("menu_Analysis")
        self.menuWidgets = QtWidgets.QMenu(self.menubar)
        self.menuWidgets.setGeometry(QtCore.QRect(2302, 118, 125, 90))
        self.menuWidgets.setObjectName("menuWidgets")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.action_exit = QtWidgets.QAction(MainWindow)
        self.action_exit.setObjectName("action_exit")
        self.action_save = QtWidgets.QAction(MainWindow)
        self.action_save.setObjectName("action_save")
        self.action_open = QtWidgets.QAction(MainWindow)
        self.action_open.setObjectName("action_open")
        self.actionMagnitude_Response = QtWidgets.QAction(MainWindow)
        self.actionMagnitude_Response.setCheckable(True)
        self.actionMagnitude_Response.setChecked(True)
        self.actionMagnitude_Response.setObjectName("actionMagnitude_Response")
        self.actionPhase_Respone = QtWidgets.QAction(MainWindow)
        self.actionPhase_Respone.setCheckable(True)
        self.actionPhase_Respone.setChecked(True)
        self.actionPhase_Respone.setObjectName("actionPhase_Respone")
        self.actionGroup_Delay = QtWidgets.QAction(MainWindow)
        self.actionGroup_Delay.setCheckable(True)
        self.actionGroup_Delay.setChecked(True)
        self.actionGroup_Delay.setObjectName("actionGroup_Delay")
        self.actionPhase_Delay = QtWidgets.QAction(MainWindow)
        self.actionPhase_Delay.setCheckable(True)
        self.actionPhase_Delay.setChecked(True)
        self.actionPhase_Delay.setObjectName("actionPhase_Delay")
        self.actionImpulse_Response = QtWidgets.QAction(MainWindow)
        self.actionImpulse_Response.setCheckable(True)
        self.actionImpulse_Response.setChecked(True)
        self.actionImpulse_Response.setObjectName("actionImpulse_Response")
        self.actionStep_Response = QtWidgets.QAction(MainWindow)
        self.actionStep_Response.setCheckable(True)
        self.actionStep_Response.setChecked(True)
        self.actionStep_Response.setObjectName("actionStep_Response")
        self.actionPole_Zero_Plot = QtWidgets.QAction(MainWindow)
        self.actionPole_Zero_Plot.setObjectName("actionPole_Zero_Plot")
        self.actionGrid = QtWidgets.QAction(MainWindow)
        self.actionGrid.setObjectName("actionGrid")
        self.actionPole_Zero_Plot_2 = QtWidgets.QAction(MainWindow)
        self.actionPole_Zero_Plot_2.setCheckable(True)
        self.actionPole_Zero_Plot_2.setChecked(True)
        self.actionPole_Zero_Plot_2.setObjectName("actionPole_Zero_Plot_2")
        self.actionIdeal_Band = QtWidgets.QAction(MainWindow)
        self.actionIdeal_Band.setCheckable(True)
        self.actionIdeal_Band.setChecked(False)
        self.actionIdeal_Band.setObjectName("actionIdeal_Band")
        self.actionGrid_2 = QtWidgets.QAction(MainWindow)
        self.actionGrid_2.setCheckable(True)
        self.actionGrid_2.setChecked(False)
        self.actionGrid_2.setObjectName("actionGrid_2")
        self.actionGrid_3 = QtWidgets.QAction(MainWindow)
        self.actionGrid_3.setObjectName("actionGrid_3")
        self.actionTabbed = QtWidgets.QAction(MainWindow)
        self.actionTabbed.setCheckable(True)
        self.actionTabbed.setObjectName("actionTabbed")
        self.actionOverlay = QtWidgets.QAction(MainWindow)
        self.actionOverlay.setCheckable(True)
        self.actionOverlay.setObjectName("actionOverlay")
        self.actionResponse_widget = QtWidgets.QAction(MainWindow)
        self.actionResponse_widget.setCheckable(True)
        self.actionResponse_widget.setChecked(True)
        self.actionResponse_widget.setObjectName("actionResponse_widget")
        self.actionSpec_widget = QtWidgets.QAction(MainWindow)
        self.actionSpec_widget.setCheckable(True)
        self.actionSpec_widget.setChecked(True)
        self.actionSpec_widget.setObjectName("actionSpec_widget")
        self.actionQuick_access = QtWidgets.QAction(MainWindow)
        self.actionQuick_access.setCheckable(True)
        self.actionQuick_access.setChecked(True)
        self.actionQuick_access.setObjectName("actionQuick_access")
        self.actionFilter_Coefficients = QtWidgets.QAction(MainWindow)
        self.actionFilter_Coefficients.setCheckable(True)
        self.actionFilter_Coefficients.setChecked(True)
        self.actionFilter_Coefficients.setObjectName("actionFilter_Coefficients")
        self.actionDesign_widget = QtWidgets.QAction(MainWindow)
        self.actionDesign_widget.setCheckable(True)
        self.actionDesign_widget.setChecked(True)
        self.actionDesign_widget.setObjectName("actionDesign_widget")
        self.actionOverlay_2 = QtWidgets.QAction(MainWindow)
        self.actionOverlay_2.setObjectName("actionOverlay_2")
        self.actionGridview = QtWidgets.QAction(MainWindow)
        self.actionGridview.setCheckable(True)
        self.actionGridview.setObjectName("actionGridview")
        self.actionDesign_widget_2 = QtWidgets.QAction(MainWindow)
        self.actionDesign_widget_2.setCheckable(True)
        self.actionDesign_widget_2.setObjectName("actionDesign_widget_2")
        self.actionQuick_access_2 = QtWidgets.QAction(MainWindow)
        self.actionQuick_access_2.setObjectName("actionQuick_access_2")
        self.actionSpec_widget_2 = QtWidgets.QAction(MainWindow)
        self.actionSpec_widget_2.setObjectName("actionSpec_widget_2")
        self.actionResponse_widget_2 = QtWidgets.QAction(MainWindow)
        self.actionResponse_widget_2.setObjectName("actionResponse_widget_2")
        self.actionDesign_Widget = QtWidgets.QAction(MainWindow)
        self.actionDesign_Widget.setCheckable(True)
        self.actionDesign_Widget.setChecked(True)
        self.actionDesign_Widget.setObjectName("actionDesign_Widget")
        self.actionQuick_Access = QtWidgets.QAction(MainWindow)
        self.actionQuick_Access.setCheckable(True)
        self.actionQuick_Access.setChecked(True)
        self.actionQuick_Access.setObjectName("actionQuick_Access")
        self.actionSpec_Widget = QtWidgets.QAction(MainWindow)
        self.actionSpec_Widget.setCheckable(True)
        self.actionSpec_Widget.setChecked(True)
        self.actionSpec_Widget.setObjectName("actionSpec_Widget")
        self.actionResponse_Widget = QtWidgets.QAction(MainWindow)
        self.actionResponse_Widget.setCheckable(True)
        self.actionResponse_Widget.setChecked(True)
        self.actionResponse_Widget.setObjectName("actionResponse_Widget")
        self.actionTabview_2 = QtWidgets.QAction(MainWindow)
        self.actionTabview_2.setCheckable(True)
        self.actionTabview_2.setChecked(True)
        self.actionTabview_2.setObjectName("actionTabview_2")
        self.actionPlot_select = QtWidgets.QAction(MainWindow)
        self.actionPlot_select.setCheckable(True)
        self.actionPlot_select.setChecked(True)
        self.actionPlot_select.setObjectName("actionPlot_select")
        self.actionBand_Diagram = QtWidgets.QAction(MainWindow)
        self.actionBand_Diagram.setCheckable(True)
        self.actionBand_Diagram.setChecked(True)
        self.actionBand_Diagram.setObjectName("actionBand_Diagram")
        self.actionCheck = QtWidgets.QAction(MainWindow)
        self.actionCheck.setObjectName("actionCheck")
        self.actionPlot_FFT_points = QtWidgets.QAction(MainWindow)
        self.actionPlot_FFT_points.setObjectName("actionPlot_FFT_points")
        self.menu_File.addAction(self.action_open)
        self.menu_File.addAction(self.action_save)
        self.menu_File.addAction(self.action_exit)
        self.menu_Analysis.addSeparator()
        self.menu_Analysis.addAction(self.actionMagnitude_Response)
        self.menu_Analysis.addAction(self.actionPhase_Respone)
        self.menu_Analysis.addAction(self.actionGroup_Delay)
        self.menu_Analysis.addAction(self.actionPhase_Delay)
        self.menu_Analysis.addAction(self.actionImpulse_Response)
        self.menu_Analysis.addAction(self.actionStep_Response)
        self.menu_Analysis.addAction(self.actionGrid_2)
        self.menu_Analysis.addAction(self.actionFilter_Coefficients)
        self.menu_Analysis.addAction(self.actionIdeal_Band)
        self.menu_Analysis.addSeparator()
        self.menu_Analysis.addAction(self.actionPole_Zero_Plot_2)
        self.menu_Analysis.addAction(self.actionBand_Diagram)
        self.menu_Analysis.addSeparator()
        self.menu_Analysis.addAction(self.actionDesign_Widget)
        self.menu_Analysis.addAction(self.actionQuick_Access)
        self.menu_Analysis.addAction(self.actionSpec_Widget)
        self.menu_Analysis.addAction(self.actionResponse_Widget)
        self.menuWidgets.addAction(self.actionGridview)
        self.menuWidgets.addAction(self.actionPlot_select)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Analysis.menuAction())
        self.menubar.addAction(self.menuWidgets.menuAction())

        self.retranslateUi(MainWindow)
        self.stackedWindows.setCurrentIndex(0)
        self.tabGroup.setCurrentIndex(0)
        self.filterspecView.setCurrentIndex(1)
        self.mfreqTabgroup.setCurrentIndex(0)
        self.mfilterspecView.setCurrentIndex(0)
        self.filterTypeWidget.setCurrentIndex(11)
        self.action_exit.triggered.connect(MainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.filterTypeComboBox, self.filterDesignTypeComboBox)
        MainWindow.setTabOrder(self.filterDesignTypeComboBox, self.endofLpfPassBandEdit)
        MainWindow.setTabOrder(self.endofLpfPassBandEdit, self.startofLpfStopBandEdit)
        MainWindow.setTabOrder(self.startofLpfStopBandEdit, self.lpfStopBandAttenEdit)
        MainWindow.setTabOrder(self.lpfStopBandAttenEdit, self.lpfPassBandRippleEdit)
        MainWindow.setTabOrder(self.lpfPassBandRippleEdit, self.startofBpfPassBandEdit)
        MainWindow.setTabOrder(self.startofBpfPassBandEdit, self.endofBpfPassBandEdit)
        MainWindow.setTabOrder(self.endofBpfPassBandEdit, self.bpfTransitionEdit)
        MainWindow.setTabOrder(self.bpfTransitionEdit, self.bpfStopBandAttenEdit)
        MainWindow.setTabOrder(self.bpfStopBandAttenEdit, self.bpfPassBandRippleEdit)
        MainWindow.setTabOrder(self.bpfPassBandRippleEdit, self.startofBnfStopBandEdit)
        MainWindow.setTabOrder(self.startofBnfStopBandEdit, self.endofBnfStopBandEdit)
        MainWindow.setTabOrder(self.endofBnfStopBandEdit, self.bnfTransitionEdit)
        MainWindow.setTabOrder(self.bnfTransitionEdit, self.bnfStopBandAttenEdit)
        MainWindow.setTabOrder(self.bnfStopBandAttenEdit, self.bnfPassBandRippleEdit)
        MainWindow.setTabOrder(self.bnfPassBandRippleEdit, self.endofHpfStopBandEdit)
        MainWindow.setTabOrder(self.endofHpfStopBandEdit, self.startofHpfPassBandEdit)
        MainWindow.setTabOrder(self.startofHpfPassBandEdit, self.hpfStopBandAttenEdit)
        MainWindow.setTabOrder(self.hpfStopBandAttenEdit, self.hpfPassBandRippleEdit)
        MainWindow.setTabOrder(self.hpfPassBandRippleEdit, self.rrcSymbolRateEdit)
        MainWindow.setTabOrder(self.rrcSymbolRateEdit, self.rrcAlphaEdit)
        MainWindow.setTabOrder(self.rrcAlphaEdit, self.rrcNumTapsEdit)
        MainWindow.setTabOrder(self.rrcNumTapsEdit, self.gausSymbolRateEdit)
        MainWindow.setTabOrder(self.gausSymbolRateEdit, self.gausBTEdit)
        MainWindow.setTabOrder(self.gausBTEdit, self.gausNumTapsEdit)
        MainWindow.setTabOrder(self.gausNumTapsEdit, self.designButton)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "GNU Radio Filter Design Tool"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.freqTab), _translate("MainWindow", "Magnitude Response"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.timeTab), _translate("MainWindow", "Filter Taps"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.phaseTab), _translate("MainWindow", "Phase Response"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.groupTab), _translate("MainWindow", "Group Delay"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.fcTab), _translate("MainWindow", "Filter Coefficients"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.impresTab), _translate("MainWindow", "Impulse Response"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.stepresTab), _translate("MainWindow", "Step Response"))
        self.tabGroup.setTabText(self.tabGroup.indexOf(self.pdelayTab), _translate("MainWindow", "Phase Delay"))
        self.filterspecView.setTabText(self.filterspecView.indexOf(self.bandDiagram), _translate("MainWindow", "Band Diagram"))
        self.addzeroPush.setToolTip(_translate("MainWindow", "Add zero"))
        self.addzeroPush.setText(_translate("MainWindow", "..."))
        self.addpolePush.setToolTip(_translate("MainWindow", "Add pole"))
        self.addpolePush.setText(_translate("MainWindow", "..."))
        self.delPush.setToolTip(_translate("MainWindow", "Delete pole/zero"))
        self.delPush.setText(_translate("MainWindow", "..."))
        self.conjPush.setToolTip(_translate("MainWindow", "Conjugate"))
        self.conjPush.setText(_translate("MainWindow", "..."))
        self.filterspecView.setTabText(self.filterspecView.indexOf(self.poleZero), _translate("MainWindow", "Pole-Zero Plot"))
        self.responseBox.setTitle(_translate("MainWindow", "Filter Responses"))
        self.checkMagres.setText(_translate("MainWindow", "Magnitude Response"))
        self.checkPhase.setText(_translate("MainWindow", "Phase Response"))
        self.checkGdelay.setText(_translate("MainWindow", "Group Delay"))
        self.checkPdelay.setText(_translate("MainWindow", "Phase Delay"))
        self.checkImpulse.setText(_translate("MainWindow", "Impulse Response"))
        self.checkStep.setText(_translate("MainWindow", "Step Response"))
        self.checkGrid.setText(_translate("MainWindow", "Grid"))
        self.checkFcoeff.setText(_translate("MainWindow", "Filter Coefficients"))
        self.checkKeepcur.setText(_translate("MainWindow", "Buffer current plots"))
        self.groupSpecs.setTitle(_translate("MainWindow", "Filter Specs"))
        self.checkBand.setText(_translate("MainWindow", "Band Diagram"))
        self.checkPzplot.setText(_translate("MainWindow", "Pole-Zero Plot"))
        self.sysParamsBox.setTitle(_translate("MainWindow", "Plot Parameter"))
        self.nfftLabel.setText(_translate("MainWindow", "Num FFT points"))
        self.mfmagPush.setToolTip(_translate("MainWindow", "Magnitude Response"))
        self.mfmagPush.setText(_translate("MainWindow", "..."))
        self.mfphasePush.setToolTip(_translate("MainWindow", "Phase Response"))
        self.mfphasePush.setText(_translate("MainWindow", "..."))
        self.mfgpdlyPush.setToolTip(_translate("MainWindow", "Group Delay"))
        self.mfgpdlyPush.setText(_translate("MainWindow", "..."))
        self.mfphdlyPush.setToolTip(_translate("MainWindow", "Phase Delay"))
        self.mfphdlyPush.setText(_translate("MainWindow", "..."))
        self.mfoverlayPush.setToolTip(_translate("MainWindow", "Overlay"))
        self.mfoverlayPush.setText(_translate("MainWindow", "..."))
        self.mfreqTabgroup.setTabText(self.mfreqTabgroup.indexOf(self.mfreqTab), _translate("MainWindow", "Frequency Response"))
        self.mttapsPush.setToolTip(_translate("MainWindow", "Filter Taps"))
        self.mttapsPush.setText(_translate("MainWindow", "..."))
        self.mtstepPush.setToolTip(_translate("MainWindow", "Step Response"))
        self.mtstepPush.setText(_translate("MainWindow", "..."))
        self.mtimpPush.setToolTip(_translate("MainWindow", "Impulse Response"))
        self.mtimpPush.setText(_translate("MainWindow", "..."))
        self.mtimeTabgroup.setTabText(self.mtimeTabgroup.indexOf(self.mtimeTab), _translate("MainWindow", "Time responses"))
        self.mfilterspecView.setTabText(self.mfilterspecView.indexOf(self.mbandDiagram), _translate("MainWindow", "Ideal Band"))
        self.maddzeroPush.setToolTip(_translate("MainWindow", "Add zero"))
        self.maddzeroPush.setText(_translate("MainWindow", "..."))
        self.maddpolePush.setToolTip(_translate("MainWindow", "Add pole"))
        self.maddpolePush.setText(_translate("MainWindow", "..."))
        self.mdelPush.setToolTip(_translate("MainWindow", "Delete pole/zero"))
        self.mdelPush.setText(_translate("MainWindow", "..."))
        self.mconjPush.setToolTip(_translate("MainWindow", "Conjugate"))
        self.mconjPush.setText(_translate("MainWindow", "..."))
        self.mfilterspecView.setTabText(self.mfilterspecView.indexOf(self.mpoleZero), _translate("MainWindow", "Pole-Zero Plot"))
        self.mfilterspecView.setTabText(self.mfilterspecView.indexOf(self.mfcTab), _translate("MainWindow", "Filter Coefficients"))
        self.fselectComboBox.setItemText(0, _translate("MainWindow", "FIR"))
        self.fselectComboBox.setItemText(1, _translate("MainWindow", "IIR"))
        self.filterTypeComboBox.setItemText(0, _translate("MainWindow", "Low Pass"))
        self.filterTypeComboBox.setItemText(1, _translate("MainWindow", "High Pass"))
        self.filterTypeComboBox.setItemText(2, _translate("MainWindow", "Band Pass"))
        self.filterTypeComboBox.setItemText(3, _translate("MainWindow", "Complex Band Pass"))
        self.filterTypeComboBox.setItemText(4, _translate("MainWindow", "Band Notch"))
        self.filterTypeComboBox.setItemText(5, _translate("MainWindow", "Root Raised Cosine"))
        self.filterTypeComboBox.setItemText(6, _translate("MainWindow", "Gaussian"))
        self.filterTypeComboBox.setItemText(7, _translate("MainWindow", "Half Band"))
        self.iirfilterBandComboBox.setItemText(0, _translate("MainWindow", "Low Pass"))
        self.iirfilterBandComboBox.setItemText(1, _translate("MainWindow", "Band Pass"))
        self.iirfilterBandComboBox.setItemText(2, _translate("MainWindow", "Band Stop"))
        self.iirfilterBandComboBox.setItemText(3, _translate("MainWindow", "High Pass"))
        self.adComboBox.setItemText(0, _translate("MainWindow", "Digital (normalized 0-1)"))
        self.adComboBox.setItemText(1, _translate("MainWindow", "Analog (rad/second)"))
        self.filterDesignTypeComboBox.setItemText(0, _translate("MainWindow", "Hamming Window"))
        self.filterDesignTypeComboBox.setItemText(1, _translate("MainWindow", "Hann Window"))
        self.filterDesignTypeComboBox.setItemText(2, _translate("MainWindow", "Blackman Window"))
        self.filterDesignTypeComboBox.setItemText(3, _translate("MainWindow", "Rectangular Window"))
        self.filterDesignTypeComboBox.setItemText(4, _translate("MainWindow", "Kaiser Window"))
        self.filterDesignTypeComboBox.setItemText(5, _translate("MainWindow", "Blackman-harris Window"))
        self.filterDesignTypeComboBox.setItemText(6, _translate("MainWindow", "Equiripple"))
        self.iirfilterTypeComboBox.setItemText(0, _translate("MainWindow", "Elliptic"))
        self.iirfilterTypeComboBox.setItemText(1, _translate("MainWindow", "Butterworth"))
        self.iirfilterTypeComboBox.setItemText(2, _translate("MainWindow", "Chebyshev-1"))
        self.iirfilterTypeComboBox.setItemText(3, _translate("MainWindow", "Chebyshev-2"))
        self.iirfilterTypeComboBox.setItemText(4, _translate("MainWindow", "Bessel"))
        self.sampleRateLabel.setText(_translate("MainWindow", "Sample Rate (sps)"))
        self.sampleRateEdit.setText(_translate("MainWindow", "320000"))
        self.filterGainLabel.setText(_translate("MainWindow", "Filter Gain"))
        self.filterGainEdit.setText(_translate("MainWindow", "2"))
        self.endofLpfPassBandLabel.setText(_translate("MainWindow", "End of Pass Band (Hz)"))
        self.endofLpfPassBandEdit.setText(_translate("MainWindow", "50000"))
        self.startofLpfStopBandLabel.setText(_translate("MainWindow", "Start of Stop Band (Hz)"))
        self.startofLpfStopBandEdit.setText(_translate("MainWindow", "60000"))
        self.lpfStopBandAttenLabel.setText(_translate("MainWindow", "Stop Band Attenuation (dB)"))
        self.lpfStopBandAttenEdit.setText(_translate("MainWindow", "40"))
        self.lpfPassBandRippleLabel.setText(_translate("MainWindow", "Pass Band Ripple (dB)"))
        self.lpfPassBandRippleEdit.setText(_translate("MainWindow", "1"))
        self.startofBpfPassBandLabel.setText(_translate("MainWindow", "Start of Pass Band (Hz)"))
        self.startofBpfPassBandEdit.setText(_translate("MainWindow", "50000"))
        self.endofBpfPassBandLabel.setText(_translate("MainWindow", "End of Pass Band (Hz)"))
        self.endofBpfPassBandEdit.setText(_translate("MainWindow", "80000"))
        self.bpfStopBandAttenEdit.setText(_translate("MainWindow", "40"))
        self.bpfStopBandAttenLabel.setText(_translate("MainWindow", "Stop Band Attenuation (dB)"))
        self.bpfTransitionLabel.setText(_translate("MainWindow", "Transition Width (Hz)"))
        self.bpfTransitionEdit.setText(_translate("MainWindow", "10000"))
        self.bpfPassBandRippleEdit.setText(_translate("MainWindow", "1"))
        self.bpfPassBandRippleLabel.setText(_translate("MainWindow", "Pass Band Ripple (dB)"))
        self.startofBnfStopBandLabel.setText(_translate("MainWindow", "Start of Stop Band (Hz)"))
        self.startofBnfStopBandEdit.setText(_translate("MainWindow", "50000"))
        self.endofBnfStopBandLabel.setText(_translate("MainWindow", "End of Stop Band (Hz)"))
        self.endofBnfStopBandEdit.setText(_translate("MainWindow", "80000"))
        self.bnfTransitionLabel.setText(_translate("MainWindow", "Transition Width (Hz)"))
        self.bnfTransitionEdit.setText(_translate("MainWindow", "10000"))
        self.bnfStopBandAttenLabel.setText(_translate("MainWindow", "Stop Band Attenuation (dB)"))
        self.bnfStopBandAttenEdit.setText(_translate("MainWindow", "48"))
        self.bnfPassBandRippleLabel.setText(_translate("MainWindow", "Pass Band Ripple (dB)"))
        self.bnfPassBandRippleEdit.setText(_translate("MainWindow", "1"))
        self.endofHpfStopBandLabel.setText(_translate("MainWindow", "End of Stop Band (Hz)"))
        self.endofHpfStopBandEdit.setText(_translate("MainWindow", "50000"))
        self.startofHpfPassBandLabel.setText(_translate("MainWindow", "Start of Pass Band (Hz)"))
        self.startofHpfPassBandEdit.setText(_translate("MainWindow", "55000"))
        self.hpfStopBandAttenLabel.setText(_translate("MainWindow", "Stop Band Attenuation (dB)"))
        self.hpfStopBandAttenEdit.setText(_translate("MainWindow", "48"))
        self.hpfPassBandRippleLabel.setText(_translate("MainWindow", "Pass Band Ripple (dB)"))
        self.hpfPassBandRippleEdit.setText(_translate("MainWindow", "1"))
        self.rrcSymbolRateLabel.setText(_translate("MainWindow", "Symbol Rate (sps)"))
        self.rrcAlphaLabel.setText(_translate("MainWindow", "Roll-off Factor"))
        self.rrcNumTapsLabel.setText(_translate("MainWindow", "Number of Taps"))
        self.rrcSymbolRateEdit.setText(_translate("MainWindow", "3200"))
        self.rrcAlphaEdit.setText(_translate("MainWindow", "15"))
        self.rrcNumTapsEdit.setText(_translate("MainWindow", "50"))
        self.gausSymbolRateLabel.setText(_translate("MainWindow", "Symbol Rate (sps)"))
        self.gausSymbolRateEdit.setText(_translate("MainWindow", "5000"))
        self.gausBTLabel.setText(_translate("MainWindow", "Roll-off Factor"))
        self.gausBTEdit.setText(_translate("MainWindow", "0.5"))
        self.gausNumTapsLabel.setText(_translate("MainWindow", "Number of Taps"))
        self.gausNumTapsEdit.setText(_translate("MainWindow", "30"))
        self.iirendofLpfPassBandLabel.setText(_translate("MainWindow", "End of Pass Band"))
        self.iirendofLpfPassBandEdit.setText(_translate("MainWindow", "0.3"))
        self.iirstartofLpfStopBandLabel.setText(_translate("MainWindow", "Start of Stop Band "))
        self.iirstartofLpfStopBandEdit.setText(_translate("MainWindow", "0.5"))
        self.iirLpfPassBandAttenLabel.setText(_translate("MainWindow", "Max loss in Pass Band (dB)"))
        self.iirLpfPassBandAttenEdit.setText(_translate("MainWindow", "1"))
        self.iirLpfStopBandRippleLabel.setText(_translate("MainWindow", "Min atten in Stop Band (dB)"))
        self.iirLpfStopBandRippleEdit.setText(_translate("MainWindow", "60"))
        self.iirendofHpfStopBandLabel.setText(_translate("MainWindow", "End of Stop Band"))
        self.iirendofHpfStopBandEdit.setText(_translate("MainWindow", "0.3"))
        self.iirstartofHpfPassBandLabel.setText(_translate("MainWindow", "Start of Pass Band "))
        self.iirstartofHpfPassBandEdit.setText(_translate("MainWindow", "0.5"))
        self.iirHpfPassBandAttenLabel.setText(_translate("MainWindow", "Max loss in Pass Band (dB)"))
        self.iirHpfPassBandAttenEdit.setText(_translate("MainWindow", "1"))
        self.iirHpfStopBandRippleLabel.setText(_translate("MainWindow", "Min atten in Stop Band (dB)"))
        self.iirHpfStopBandRippleEdit.setText(_translate("MainWindow", "60"))
        self.iirendofBpfStopBandLabel1.setText(_translate("MainWindow", "End of Stop Band-1"))
        self.iirendofBpfStopBandEdit1.setText(_translate("MainWindow", "0.2"))
        self.iirstartofBpfPassBandLabel.setText(_translate("MainWindow", "Start of Pass Band "))
        self.iirstartofBpfPassBandEdit.setText(_translate("MainWindow", "0.3"))
        self.iirendofBpfPassBandLabel.setText(_translate("MainWindow", "End of Pass Band "))
        self.iirendofBpfPassBandEdit.setText(_translate("MainWindow", "0.5"))
        self.iirstartofBpfStopBandLabel2.setText(_translate("MainWindow", "Start of Stop Band-2"))
        self.iirstartofBpfStopBandEdit2.setText(_translate("MainWindow", "0.6"))
        self.iirBpfPassBandAttenLabel.setText(_translate("MainWindow", "Max loss in Pass Band (dB)"))
        self.iirBpfPassBandAttenEdit.setText(_translate("MainWindow", "1"))
        self.iirBpfStopBandRippleLabel.setText(_translate("MainWindow", "Min atten in Stop Band (dB)"))
        self.iirBpfStopBandRippleEdit.setText(_translate("MainWindow", "60"))
        self.iirendofBsfPassBandLabel1.setText(_translate("MainWindow", "End of Pass Band-1"))
        self.iirendofBsfPassBandEdit1.setText(_translate("MainWindow", "0.2"))
        self.iirstartofBsfStopBandLabel.setText(_translate("MainWindow", "Start of Stop Band "))
        self.iirstartofBsfStopBandEdit.setText(_translate("MainWindow", "0.3"))
        self.iirendofBsfStopBandLabel.setText(_translate("MainWindow", "End of Stop Band "))
        self.iirendofBsfStopBandEdit.setText(_translate("MainWindow", "0.6"))
        self.iirstartofBsfPassBandLabel2.setText(_translate("MainWindow", "Start of Pass Band-2"))
        self.iirstartofBsfPassBandEdit2.setText(_translate("MainWindow", "0.7"))
        self.iirBsfPassBandAttenLabel.setText(_translate("MainWindow", "Max loss in Pass Band (dB)"))
        self.iirBsfPassBandAttenEdit.setText(_translate("MainWindow", "1"))
        self.iirBsfStopBandRippleLabel.setText(_translate("MainWindow", "Min atten in Stop Band (dB)"))
        self.iirBsfStopBandRippleEdit.setText(_translate("MainWindow", "60"))
        self.besselordLabel.setText(_translate("MainWindow", "Filter Order"))
        self.besselordEdit.setText(_translate("MainWindow", "10"))
        self.iirbesselcritLabel1.setText(_translate("MainWindow", "Critical point-1"))
        self.iirbesselcritEdit1.setText(_translate("MainWindow", "0.2"))
        self.iirbesselcritEdit2.setText(_translate("MainWindow", "0.5"))
        self.iirbesselcritLabel2.setText(_translate("MainWindow", "Critical point-2"))
        self.firhbordLabel.setText(_translate("MainWindow", "Filter Order"))
        self.firhbordEdit.setText(_translate("MainWindow", "34"))
        self.firhbtrEditLabel2.setText(_translate("MainWindow", "Transition width\n"
" (from fs/4)"))
        self.firhbtrEdit.setText(_translate("MainWindow", "10000"))
        self.filterPropsBox.setTitle(_translate("MainWindow", "Filter Properties"))
        self.nTapsLabel.setText(_translate("MainWindow", "Number of Taps:"))
        self.designButton.setText(_translate("MainWindow", "Design"))
        self.menu_File.setTitle(_translate("MainWindow", "&File"))
        self.menu_Analysis.setTitle(_translate("MainWindow", "A&nalysis"))
        self.menuWidgets.setTitle(_translate("MainWindow", "V&iew"))
        self.action_exit.setText(_translate("MainWindow", "E&xit"))
        self.action_save.setText(_translate("MainWindow", "&Save"))
        self.action_save.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.action_open.setText(_translate("MainWindow", "&Open"))
        self.action_open.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.actionMagnitude_Response.setText(_translate("MainWindow", "&Magnitude Response"))
        self.actionPhase_Respone.setText(_translate("MainWindow", "&Phase Respone"))
        self.actionGroup_Delay.setText(_translate("MainWindow", "&Group Delay"))
        self.actionPhase_Delay.setText(_translate("MainWindow", "P&hase Delay"))
        self.actionImpulse_Response.setText(_translate("MainWindow", "&Impulse Response"))
        self.actionStep_Response.setText(_translate("MainWindow", "&Step Response"))
        self.actionPole_Zero_Plot.setText(_translate("MainWindow", "Pole-Zero Plot"))
        self.actionGrid.setText(_translate("MainWindow", "Grid"))
        self.actionPole_Zero_Plot_2.setText(_translate("MainWindow", "Pole &Zero Plot"))
        self.actionIdeal_Band.setText(_translate("MainWindow", "Id&eal Band"))
        self.actionGrid_2.setText(_translate("MainWindow", "Grid"))
        self.actionGrid_3.setText(_translate("MainWindow", "Grid"))
        self.actionTabbed.setText(_translate("MainWindow", "Tabbed"))
        self.actionOverlay.setText(_translate("MainWindow", "Overlay"))
        self.actionResponse_widget.setText(_translate("MainWindow", "Response widget"))
        self.actionSpec_widget.setText(_translate("MainWindow", "Spec widget"))
        self.actionQuick_access.setText(_translate("MainWindow", "Quick access"))
        self.actionFilter_Coefficients.setText(_translate("MainWindow", "&Filter Coefficients"))
        self.actionDesign_widget.setText(_translate("MainWindow", "Design widget"))
        self.actionOverlay_2.setText(_translate("MainWindow", "Overlay"))
        self.actionGridview.setText(_translate("MainWindow", "&Gridview"))
        self.actionDesign_widget_2.setText(_translate("MainWindow", "Design widget"))
        self.actionQuick_access_2.setText(_translate("MainWindow", "Quick access"))
        self.actionSpec_widget_2.setText(_translate("MainWindow", "Spec widget"))
        self.actionResponse_widget_2.setText(_translate("MainWindow", "Response widget"))
        self.actionDesign_Widget.setText(_translate("MainWindow", "&Design Widget"))
        self.actionQuick_Access.setText(_translate("MainWindow", "&Quick Access"))
        self.actionSpec_Widget.setText(_translate("MainWindow", "Spec &Widget"))
        self.actionResponse_Widget.setText(_translate("MainWindow", "&Response Widget"))
        self.actionTabview_2.setText(_translate("MainWindow", "Tabview"))
        self.actionPlot_select.setText(_translate("MainWindow", "&Plot select"))
        self.actionBand_Diagram.setText(_translate("MainWindow", "&Band Diagram"))
        self.actionCheck.setText(_translate("MainWindow", "check"))
        self.actionPlot_FFT_points.setText(_translate("MainWindow", "Plot FFT points"))

from .GrFilterPlotWidget import GrFilterPlotWidget
from .bandgraphicsview import BandGraphicsView
from .polezero_plot import PzPlot
from . import icons_rc



#!D:\bld\gnuradio_1623414383812\_h_env\python.exe
#
# Copyright 2008,2011,2013 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
#


from gnuradio import gr, eng_notation
from optparse import OptionParser
from gnuradio.eng_option import eng_option
import threading
import sys, time, math

from gnuradio import digital
from gnuradio import blocks

# from current dir
from uhd_interface import uhd_receiver

n2s = eng_notation.num_to_str

class status_thread(threading.Thread):
    def __init__(self, tb):
        threading.Thread.__init__(self)
        self.setDaemon(1)
        self.tb = tb
        self.done = False
        self.start()

    def run(self):
        while not self.done:
            print("Freq. Offset: {0:5.0f} Hz  Timing Offset: {1:10.1f} ppm  Estimated SNR: {2:4.1f} dB  BER: {3:g}".format(
                tb.frequency_offset(), tb.timing_offset()*1e6, tb.snr(), tb.ber()))
            try:
                time.sleep(1.0)
            except KeyboardInterrupt:
                self.done = True



class bert_receiver(gr.hier_block2):
    def __init__(self, bitrate,
                 constellation, samples_per_symbol,
                 differential, excess_bw, gray_coded,
                 freq_bw, timing_bw, phase_bw,
                 verbose, log):

        gr.hier_block2.__init__(self, "bert_receive",
                                gr.io_signature(1, 1, gr.sizeof_gr_complex), # Input signature
                                gr.io_signature(0, 0, 0))                    # Output signature

        self._bitrate = bitrate

        self._demod = digital.generic_demod(constellation, differential,
                                            samples_per_symbol,
                                            gray_coded, excess_bw,
                                            freq_bw, timing_bw, phase_bw,
                                            verbose, log)

        self._symbol_rate = self._bitrate / self._demod.bits_per_symbol()
        self._sample_rate = self._symbol_rate * samples_per_symbol

        # Add an SNR probe on the demodulated constellation
        self._snr_probe = digital.probe_mpsk_snr_est_c(digital.SNR_EST_M2M4, 1000,
                                                       alpha=10.0 / self._symbol_rate)
        self.connect(self._demod.time_recov, self._snr_probe)

        # Descramble BERT sequence.  A channel error will create 3 incorrect bits
        self._descrambler = digital.descrambler_bb(0x8A, 0x7F, 7) # CCSDS 7-bit descrambler

        # Measure BER by the density of 0s in the stream
        self._ber = digital.probe_density_b(1.0 / self._symbol_rate)

        self.connect(self, self._demod, self._descrambler, self._ber)

    def frequency_offset(self):
        return self._demod.freq_recov.get_frequency()*self._sample_rate/(2*math.pi)

    def timing_offset(self):
        return self._demod.time_recov.clock_rate()

    def snr(self):
        return self._snr_probe.snr()

    def ber(self):
        return (1.0-self._ber.density()) / 3.0



class rx_psk_block(gr.top_block):
    def __init__(self, demod, options):

        gr.top_block.__init__(self, "rx_mpsk")

        self._demodulator_class = demod

        # Get demod_kwargs
        demod_kwargs = self._demodulator_class.extract_kwargs_from_options(options)

        # demodulator
        self._demodulator = self._demodulator_class(**demod_kwargs)

        if(options.rx_freq is not None):
            symbol_rate = options.bitrate / self._demodulator.bits_per_symbol()
            self._source = uhd_receiver(options.args, symbol_rate,
                                        options.samples_per_symbol,
                                        options.rx_freq, options.rx_gain,
                                        options.spec,
                                        options.antenna, options.verbose)
            options.samples_per_symbol = self._source._sps

        elif(options.from_file is not None):
            self._source = blocks.file_source(gr.sizeof_gr_complex, options.from_file)
        else:
            self._source = blocks.null_source(gr.sizeof_gr_complex)

        # Create the BERT receiver
        self._receiver = bert_receiver(options.bitrate,
                                       self._demodulator._constellation,
                                       options.samples_per_symbol,
                                       options.differential,
                                       options.excess_bw,
                                       gray_coded=True,
                                       freq_bw=options.freq_bw,
                                       timing_bw=options.timing_bw,
                                       phase_bw=options.phase_bw,
                                       verbose=options.verbose,
                                       log=options.log)

        self.connect(self._source, self._receiver)

    def snr(self):
        return self._receiver.snr()

    def mag(self):
        return self._receiver.signal_mean()

    def var(self):
        return self._receiver.noise_variance()

    def ber(self):
        return self._receiver.ber()

    def frequency_offset(self):
        return self._receiver.frequency_offset()

    def timing_offset(self):
        return self._receiver.timing_offset()


def get_options(demods):
    parser = OptionParser(option_class=eng_option, conflict_handler="resolve")
    parser.add_option("","--from-file", default=None,
                      help="input file of samples to demod")
    parser.add_option("-m", "--modulation", type="choice", choices=list(demods.keys()),
                      default='psk',
                      help="Select modulation from: %s [default=%%default]"
                            % (', '.join(list(demods.keys())),))
    parser.add_option("-r", "--bitrate", type="eng_float", default=250e3,
                      help="Select modulation bit rate (default=%default)")
    parser.add_option("-S", "--samples-per-symbol", type="float", default=2,
                      help="set samples/symbol [default=%default]")
    if not parser.has_option("--verbose"):
        parser.add_option("-v", "--verbose", action="store_true", default=False)
    if not parser.has_option("--log"):
        parser.add_option("", "--log", action="store_true", default=False,
                      help="Log all parts of flow graph to files (CAUTION: lots of data)")

    uhd_receiver.add_options(parser)

    demods = digital.modulation_utils.type_1_demods()
    for mod in list(demods.values()):
        mod.add_options(parser)

    (options, args) = parser.parse_args()
    if len(args) != 0:
        parser.print_help()
        sys.exit(1)

    return (options, args)


if __name__ == "__main__":
    print ("""Warning: this example in its current shape is deprecated and
            will be removed or fundamentally reworked in a coming GNU Radio
            release.""")
    demods = digital.modulation_utils.type_1_demods()

    (options, args) = get_options(demods)

    demod = demods[options.modulation]
    tb = rx_psk_block(demod, options)

    print("\n*** SNR estimator is inaccurate below about 7dB")
    print("*** BER estimator is inaccurate above about 10%\n")
    updater = status_thread(tb)

    try:
        tb.run()
    except KeyboardInterrupt:
        updater.done = True
        updater = None



#!/usr/bin/env python
#
# Copyright 2015 Free Software Foundation, Inc.
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
#


import numpy as np
from .common import PolarCommon
from . import helper_functions as hf


class PolarEncoder(PolarCommon):
    def __init__(self, n, k, frozen_bit_position, frozenbits=None):
        PolarCommon.__init__(self, n, k, frozen_bit_position, frozenbits)
        self.G = hf.get_Fn(n)

    def get_gn(self):
        return self.G

    def _prepare_input_data(self, vec):
        vec = self._insert_frozen_bits(vec)
        vec = self._reverse_bits(vec)
        return vec

    def _encode_matrix(self, data):
        data = np.dot(data, self.G) % 2
        data = data.astype(dtype=int)
        return data

    def encode(self, data, is_packed=False):
        if not len(data) == self.K:
            raise ValueError("len(data)={0} is not equal to k={1}!".format(len(data), self.K))
        if is_packed:
            data = np.unpackbits(data)
        if np.max(data) > 1 or np.min(data) < 0:
            raise ValueError("can only encode bits!")
        data = self._prepare_input_data(data)
        data = self._encode_efficient(data)
        if is_packed:
            data = np.packbits(data)
        return data

    def encode_systematic(self, data):
        if not len(data) == self.K:
            raise ValueError("len(data)={0} is not equal to k={1}!".format(len(data), self.K))
        if np.max(data) > 1 or np.min(data) < 0:
            raise ValueError("can only encode bits!")

        d = self._insert_frozen_bits(data)
        d = self._encode_natural_order(d)
        d = self._reverse_bits(d)
        d[self.frozen_bit_position] = 0
        d = self._encode_natural_order(d)
        # d = self._reverse_bits(d) # for more accuracy, do another bit-reversal. or don't for computational simplicity.
        return d


def test_systematic_encoder(encoder, ntests, k):
    for n in range(ntests):
        bits = np.random.randint(2, size=k)
        x = encoder.encode_systematic(bits)
        x = encoder._reverse_bits(x)
        u_hat = encoder._extract_info_bits(x)

        assert (bits == u_hat).all()
        # print((bits == u_hat).all())


def compare_results(encoder, ntests, k):
    for n in range(ntests):
        bits = np.random.randint(2, size=k)
        preped = encoder._prepare_input_data(bits)
        menc = encoder._encode_matrix(preped)
        fenc = encoder._encode_efficient(preped)
        if (menc == fenc).all() == False:
            return False
    return True


def test_pseudo_rate_1_encoder(encoder, ntests, k):
    for n in range(ntests):
        bits = np.random.randint(2, size=k)
        u = encoder._prepare_input_data(bits)
        fenc = encoder._encode_efficient(u)
        u_hat = encoder._encode_efficient(fenc)
        if not (u_hat == u).all():
            print('rate-1 encoder/decoder failed')
            print(u)
            print(u_hat)
            return False
    return True


def test_encoder_impls():
    print('Compare encoder implementations, matrix vs. efficient')
    ntests = 1000
    n = 16
    k = 8
    # frozenbits = np.zeros(n - k)
    # frozenbitposition8 = np.array((0, 1, 2, 4), dtype=int)  # keep it!
    frozenbitposition = np.array((0, 1, 2, 3, 4, 5, 8, 9), dtype=int)
    encoder = PolarEncoder(n, k, frozenbitposition)  #, frozenbits)
    print('result:', compare_results(encoder, ntests, k))

    print('Test rate-1 encoder/decoder chain results')
    r1_test = test_pseudo_rate_1_encoder(encoder, ntests, k)
    print('Test rate-1 encoder/decoder:', r1_test)
    test_systematic_encoder(encoder, ntests, k)


def main():
    test_encoder_impls()


if __name__ == '__main__':
    main()
